# `royalnet.bard`

The subpackage providing all classes related to music files.

It requires the `bard` extra to be installed (the [`ffmpeg_python`](https://pypi.org/project/ffmpeg-python/), [`youtube_dl`](https://pypi.org/project/youtube_dl/) and [`eyed3`](https://pypi.org/project/eyeD3/) packages).

You can install it with: 
```
pip install royalnet[bard]
```
